@@ -424,7 +424,7 @@ class TernaryAxesSubplot(object):
                                          permutation=permutation, **kwargs)
 
     def heatmap(self, data, scale=None, cmap=None, scientific=False,
-                style='triangular', colorbar=True, colormap=True,
+                style='triangular', colorbar=True, use_rgba=False,
                 vmin=None, vmax=None, cbarlabel=None, cb_kwargs=None):
         permutation = self._permutation
         if not scale:
@@ -434,7 +434,7 @@ class TernaryAxesSubplot(object):
         ax = self.get_axes()
         heatmapping.heatmap(data, scale, cmap=cmap, style=style, ax=ax,
                             scientific=scientific, colorbar=colorbar,
-                            permutation=permutation, colormap=colormap,
+                            permutation=permutation, use_rgba=use_rgba,
                             vmin=vmin, vmax=vmax, cbarlabel=cbarlabel,
                             cb_kwargs=cb_kwargs)
 
